assetpb

package
v1.22.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 18, 2026 License: Apache-2.0 Imports: 16 Imported by: 1

Documentation

Index

Constants

const (
	AssetService_CreateFeed_FullMethodName = "/google.cloud.asset.v1p2beta1.AssetService/CreateFeed"
	AssetService_GetFeed_FullMethodName    = "/google.cloud.asset.v1p2beta1.AssetService/GetFeed"
	AssetService_ListFeeds_FullMethodName  = "/google.cloud.asset.v1p2beta1.AssetService/ListFeeds"
	AssetService_UpdateFeed_FullMethodName = "/google.cloud.asset.v1p2beta1.AssetService/UpdateFeed"
	AssetService_DeleteFeed_FullMethodName = "/google.cloud.asset.v1p2beta1.AssetService/DeleteFeed"
)

Variables

var (
	ContentType_name = map[int32]string{
		0: "CONTENT_TYPE_UNSPECIFIED",
		1: "RESOURCE",
		2: "IAM_POLICY",
	}
	ContentType_value = map[string]int32{
		"CONTENT_TYPE_UNSPECIFIED": 0,
		"RESOURCE":                 1,
		"IAM_POLICY":               2,
	}
)

Enum value maps for ContentType.

var AssetService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.asset.v1p2beta1.AssetService",
	HandlerType: (*AssetServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateFeed",
			Handler:    _AssetService_CreateFeed_Handler,
		},
		{
			MethodName: "GetFeed",
			Handler:    _AssetService_GetFeed_Handler,
		},
		{
			MethodName: "ListFeeds",
			Handler:    _AssetService_ListFeeds_Handler,
		},
		{
			MethodName: "UpdateFeed",
			Handler:    _AssetService_UpdateFeed_Handler,
		},
		{
			MethodName: "DeleteFeed",
			Handler:    _AssetService_DeleteFeed_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/asset/v1p2beta1/asset_service.proto",
}

AssetService_ServiceDesc is the grpc.ServiceDesc for AssetService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_google_cloud_asset_v1p2beta1_asset_service_proto protoreflect.FileDescriptor
var File_google_cloud_asset_v1p2beta1_assets_proto protoreflect.FileDescriptor

Functions

func RegisterAssetServiceServer

func RegisterAssetServiceServer(s grpc.ServiceRegistrar, srv AssetServiceServer)

Types

type Asset

type Asset struct {

	// The full name of the asset. Example:
	// `//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1`
	//
	// See [Resource
	// names](https://cloud.google.com/apis/design/resource_names#full_resource_name)
	// for more information.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The type of the asset. Example: `compute.googleapis.com/Disk`
	//
	// See [Supported asset
	// types](https://cloud.google.com/asset-inventory/docs/supported-asset-types)
	// for more information.
	AssetType string `protobuf:"bytes,2,opt,name=asset_type,json=assetType,proto3" json:"asset_type,omitempty"`
	// A representation of the resource.
	Resource *Resource `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
	// A representation of the IAM policy set on a Google Cloud resource.
	// There can be a maximum of one IAM policy set on any given resource.
	// In addition, IAM policies inherit their granted access scope from any
	// policies set on parent resources in the resource hierarchy. Therefore, the
	// effectively policy is the union of both the policy set on this resource
	// and each policy set on all of the resource's ancestry resource levels in
	// the hierarchy. See
	// [this topic](https://cloud.google.com/iam/help/allow-policies/inheritance)
	// for more information.
	IamPolicy *iampb.Policy `protobuf:"bytes,4,opt,name=iam_policy,json=iamPolicy,proto3" json:"iam_policy,omitempty"`
	// The ancestry path of an asset in Google Cloud [resource
	// hierarchy](https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy),
	// represented as a list of relative resource names. An ancestry path starts
	// with the closest ancestor in the hierarchy and ends at root. If the asset
	// is a project, folder, or organization, the ancestry path starts from the
	// asset itself.
	//
	// Example: `["projects/123456789", "folders/5432", "organizations/1234"]`
	Ancestors []string `protobuf:"bytes,6,rep,name=ancestors,proto3" json:"ancestors,omitempty"`
	// A representation of an [access
	// policy](https://cloud.google.com/access-context-manager/docs/overview#access-policies).
	//
	// Types that are assignable to AccessContextPolicy:
	//
	//	*Asset_AccessPolicy
	//	*Asset_AccessLevel
	//	*Asset_ServicePerimeter
	AccessContextPolicy isAsset_AccessContextPolicy `protobuf_oneof:"access_context_policy"`
	// A representation of an [organization
	// policy](https://cloud.google.com/resource-manager/docs/organization-policy/overview#organization_policy).
	// There can be more than one organization policy with different constraints
	// set on a given resource.
	OrgPolicy []*orgpolicypb.Policy `protobuf:"bytes,10,rep,name=org_policy,json=orgPolicy,proto3" json:"org_policy,omitempty"`
	// contains filtered or unexported fields
}

An asset in Google Cloud. An asset can be any resource in the Google Cloud [resource hierarchy](https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy), a resource outside the Google Cloud resource hierarchy (such as Google Kubernetes Engine clusters and objects), or a policy (e.g. IAM policy). See [Supported asset types](https://cloud.google.com/asset-inventory/docs/supported-asset-types) for more information.

func (*Asset) Descriptor deprecated

func (*Asset) Descriptor() ([]byte, []int)

Deprecated: Use Asset.ProtoReflect.Descriptor instead.

func (*Asset) GetAccessContextPolicy added in v1.16.0

func (m *Asset) GetAccessContextPolicy() isAsset_AccessContextPolicy

func (*Asset) GetAccessLevel added in v1.16.0

func (x *Asset) GetAccessLevel() *accesscontextmanagerpb.AccessLevel

func (*Asset) GetAccessPolicy added in v1.16.0

func (x *Asset) GetAccessPolicy() *accesscontextmanagerpb.AccessPolicy

func (*Asset) GetAncestors

func (x *Asset) GetAncestors() []string

func (*Asset) GetAssetType

func (x *Asset) GetAssetType() string

func (*Asset) GetIamPolicy

func (x *Asset) GetIamPolicy() *iampb.Policy

func (*Asset) GetName

func (x *Asset) GetName() string

func (*Asset) GetOrgPolicy added in v1.16.0

func (x *Asset) GetOrgPolicy() []*orgpolicypb.Policy

func (*Asset) GetResource

func (x *Asset) GetResource() *Resource

func (*Asset) GetServicePerimeter added in v1.16.0

func (x *Asset) GetServicePerimeter() *accesscontextmanagerpb.ServicePerimeter

func (*Asset) ProtoMessage

func (*Asset) ProtoMessage()

func (*Asset) ProtoReflect

func (x *Asset) ProtoReflect() protoreflect.Message

func (*Asset) Reset

func (x *Asset) Reset()

func (*Asset) String

func (x *Asset) String() string

type AssetServiceClient

type AssetServiceClient interface {
	// Creates a feed in a parent project/folder/organization to listen to its
	// asset updates.
	CreateFeed(ctx context.Context, in *CreateFeedRequest, opts ...grpc.CallOption) (*Feed, error)
	// Gets details about an asset feed.
	GetFeed(ctx context.Context, in *GetFeedRequest, opts ...grpc.CallOption) (*Feed, error)
	// Lists all asset feeds in a parent project/folder/organization.
	ListFeeds(ctx context.Context, in *ListFeedsRequest, opts ...grpc.CallOption) (*ListFeedsResponse, error)
	// Updates an asset feed configuration.
	UpdateFeed(ctx context.Context, in *UpdateFeedRequest, opts ...grpc.CallOption) (*Feed, error)
	// Deletes an asset feed.
	DeleteFeed(ctx context.Context, in *DeleteFeedRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}

AssetServiceClient is the client API for AssetService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AssetServiceServer

type AssetServiceServer interface {
	// Creates a feed in a parent project/folder/organization to listen to its
	// asset updates.
	CreateFeed(context.Context, *CreateFeedRequest) (*Feed, error)
	// Gets details about an asset feed.
	GetFeed(context.Context, *GetFeedRequest) (*Feed, error)
	// Lists all asset feeds in a parent project/folder/organization.
	ListFeeds(context.Context, *ListFeedsRequest) (*ListFeedsResponse, error)
	// Updates an asset feed configuration.
	UpdateFeed(context.Context, *UpdateFeedRequest) (*Feed, error)
	// Deletes an asset feed.
	DeleteFeed(context.Context, *DeleteFeedRequest) (*emptypb.Empty, error)
}

AssetServiceServer is the server API for AssetService service. All implementations should embed UnimplementedAssetServiceServer for forward compatibility

type Asset_AccessLevel added in v1.16.0

type Asset_AccessLevel struct {
	// Please also refer to the [access level user
	// guide](https://cloud.google.com/access-context-manager/docs/overview#access-levels).
	AccessLevel *accesscontextmanagerpb.AccessLevel `protobuf:"bytes,8,opt,name=access_level,json=accessLevel,proto3,oneof"`
}

type Asset_AccessPolicy added in v1.16.0

type Asset_AccessPolicy struct {
	// Please also refer to the [access policy user
	// guide](https://cloud.google.com/access-context-manager/docs/overview#access-policies).
	AccessPolicy *accesscontextmanagerpb.AccessPolicy `protobuf:"bytes,7,opt,name=access_policy,json=accessPolicy,proto3,oneof"`
}

type Asset_ServicePerimeter added in v1.16.0

type Asset_ServicePerimeter struct {
	// Please also refer to the [service perimeter user
	// guide](https://cloud.google.com/vpc-service-controls/docs/overview).
	ServicePerimeter *accesscontextmanagerpb.ServicePerimeter `protobuf:"bytes,9,opt,name=service_perimeter,json=servicePerimeter,proto3,oneof"`
}

type BatchGetAssetsHistoryResponse added in v1.16.0

type BatchGetAssetsHistoryResponse struct {

	// A list of assets with valid time windows.
	Assets []*TemporalAsset `protobuf:"bytes,1,rep,name=assets,proto3" json:"assets,omitempty"`
	// contains filtered or unexported fields
}

Batch get assets history response.

func (*BatchGetAssetsHistoryResponse) Descriptor deprecated added in v1.16.0

func (*BatchGetAssetsHistoryResponse) Descriptor() ([]byte, []int)

Deprecated: Use BatchGetAssetsHistoryResponse.ProtoReflect.Descriptor instead.

func (*BatchGetAssetsHistoryResponse) GetAssets added in v1.16.0

func (x *BatchGetAssetsHistoryResponse) GetAssets() []*TemporalAsset

func (*BatchGetAssetsHistoryResponse) ProtoMessage added in v1.16.0

func (*BatchGetAssetsHistoryResponse) ProtoMessage()

func (*BatchGetAssetsHistoryResponse) ProtoReflect added in v1.16.0

func (*BatchGetAssetsHistoryResponse) Reset added in v1.16.0

func (x *BatchGetAssetsHistoryResponse) Reset()

func (*BatchGetAssetsHistoryResponse) String added in v1.16.0

type ContentType

type ContentType int32

Asset content type.

const (
	// Unspecified content type.
	ContentType_CONTENT_TYPE_UNSPECIFIED ContentType = 0
	// Resource metadata.
	ContentType_RESOURCE ContentType = 1
	// The actual IAM policy set on a resource.
	ContentType_IAM_POLICY ContentType = 2
)

func (ContentType) Descriptor

func (ContentType) Enum

func (x ContentType) Enum() *ContentType

func (ContentType) EnumDescriptor deprecated

func (ContentType) EnumDescriptor() ([]byte, []int)

Deprecated: Use ContentType.Descriptor instead.

func (ContentType) Number

func (x ContentType) Number() protoreflect.EnumNumber

func (ContentType) String

func (x ContentType) String() string

func (ContentType) Type

type CreateFeedRequest

type CreateFeedRequest struct {

	// Required. The name of the project/folder/organization where this feed
	// should be created in. It can only be an organization number (such as
	// "organizations/123"), a folder number (such as "folders/123"), a project ID
	// (such as "projects/my-project-id"), or a project number (such as
	// "projects/12345").
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. This is the client-assigned asset feed identifier and it needs to
	// be unique under a specific parent project/folder/organization.
	FeedId string `protobuf:"bytes,2,opt,name=feed_id,json=feedId,proto3" json:"feed_id,omitempty"`
	// Required. The feed details. The field `name` must be empty and it will be
	// generated in the format of: projects/project_number/feeds/feed_id
	// folders/folder_number/feeds/feed_id
	// organizations/organization_number/feeds/feed_id
	Feed *Feed `protobuf:"bytes,3,opt,name=feed,proto3" json:"feed,omitempty"`
	// contains filtered or unexported fields
}

Create asset feed request.

func (*CreateFeedRequest) Descriptor deprecated

func (*CreateFeedRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateFeedRequest.ProtoReflect.Descriptor instead.

func (*CreateFeedRequest) GetFeed

func (x *CreateFeedRequest) GetFeed() *Feed

func (*CreateFeedRequest) GetFeedId

func (x *CreateFeedRequest) GetFeedId() string

func (*CreateFeedRequest) GetParent

func (x *CreateFeedRequest) GetParent() string

func (*CreateFeedRequest) ProtoMessage

func (*CreateFeedRequest) ProtoMessage()

func (*CreateFeedRequest) ProtoReflect

func (x *CreateFeedRequest) ProtoReflect() protoreflect.Message

func (*CreateFeedRequest) Reset

func (x *CreateFeedRequest) Reset()

func (*CreateFeedRequest) String

func (x *CreateFeedRequest) String() string

type DeleteFeedRequest

type DeleteFeedRequest struct {

	// Required. The name of the feed and it must be in the format of:
	// projects/project_number/feeds/feed_id
	// folders/folder_number/feeds/feed_id
	// organizations/organization_number/feeds/feed_id
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteFeedRequest) Descriptor deprecated

func (*DeleteFeedRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteFeedRequest.ProtoReflect.Descriptor instead.

func (*DeleteFeedRequest) GetName

func (x *DeleteFeedRequest) GetName() string

func (*DeleteFeedRequest) ProtoMessage

func (*DeleteFeedRequest) ProtoMessage()

func (*DeleteFeedRequest) ProtoReflect

func (x *DeleteFeedRequest) ProtoReflect() protoreflect.Message

func (*DeleteFeedRequest) Reset

func (x *DeleteFeedRequest) Reset()

func (*DeleteFeedRequest) String

func (x *DeleteFeedRequest) String() string

type ExportAssetsResponse added in v1.16.0

type ExportAssetsResponse struct {

	// Time the snapshot was taken.
	ReadTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=read_time,json=readTime,proto3" json:"read_time,omitempty"`
	// Output configuration indicating where the results were output to.
	OutputConfig *OutputConfig `protobuf:"bytes,2,opt,name=output_config,json=outputConfig,proto3" json:"output_config,omitempty"`
	// contains filtered or unexported fields
}

The export asset response. This message is returned by the [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation] method in the returned [google.longrunning.Operation.response][google.longrunning.Operation.response] field.

func (*ExportAssetsResponse) Descriptor deprecated added in v1.16.0

func (*ExportAssetsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ExportAssetsResponse.ProtoReflect.Descriptor instead.

func (*ExportAssetsResponse) GetOutputConfig added in v1.16.0

func (x *ExportAssetsResponse) GetOutputConfig() *OutputConfig

func (*ExportAssetsResponse) GetReadTime added in v1.16.0

func (x *ExportAssetsResponse) GetReadTime() *timestamppb.Timestamp

func (*ExportAssetsResponse) ProtoMessage added in v1.16.0

func (*ExportAssetsResponse) ProtoMessage()

func (*ExportAssetsResponse) ProtoReflect added in v1.16.0

func (x *ExportAssetsResponse) ProtoReflect() protoreflect.Message

func (*ExportAssetsResponse) Reset added in v1.16.0

func (x *ExportAssetsResponse) Reset()

func (*ExportAssetsResponse) String added in v1.16.0

func (x *ExportAssetsResponse) String() string

type Feed

type Feed struct {

	// Required. The format will be
	// projects/{project_number}/feeds/{client-assigned_feed_identifier} or
	// folders/{folder_number}/feeds/{client-assigned_feed_identifier} or
	// organizations/{organization_number}/feeds/{client-assigned_feed_identifier}
	//
	// The client-assigned feed identifier must be unique within the parent
	// project/folder/organization.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// A list of the full names of the assets to receive updates. You must specify
	// either or both of asset_names and asset_types. Only asset updates matching
	// specified asset_names or asset_types are exported to the feed. For
	// example:
	// `//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1`.
	// See [Resource
	// Names](https://cloud.google.com/apis/design/resource_names#full_resource_name)
	// for more info.
	AssetNames []string `protobuf:"bytes,2,rep,name=asset_names,json=assetNames,proto3" json:"asset_names,omitempty"`
	// A list of types of the assets to receive updates. You must specify either
	// or both of asset_names and asset_types. Only asset updates matching
	// specified asset_names or asset_types are exported to the feed.
	// For example:
	// "compute.googleapis.com/Disk" See [Introduction to Cloud Asset
	// Inventory](https://cloud.google.com/resource-manager/docs/cloud-asset-inventory/overview)
	// for all supported asset types.
	AssetTypes []string `protobuf:"bytes,3,rep,name=asset_types,json=assetTypes,proto3" json:"asset_types,omitempty"`
	// Asset content type. If not specified, no content but the asset name and
	// type will be returned.
	ContentType ContentType `` /* 141-byte string literal not displayed */
	// Required. Feed output configuration defining where the asset updates are
	// published to.
	FeedOutputConfig *FeedOutputConfig `protobuf:"bytes,5,opt,name=feed_output_config,json=feedOutputConfig,proto3" json:"feed_output_config,omitempty"`
	// contains filtered or unexported fields
}

An asset feed used to export asset updates to a destinations. An asset feed filter controls what updates are exported. The asset feed must be created within a project, organization, or folder. Supported destinations are: Cloud Pub/Sub topics.

func (*Feed) Descriptor deprecated

func (*Feed) Descriptor() ([]byte, []int)

Deprecated: Use Feed.ProtoReflect.Descriptor instead.

func (*Feed) GetAssetNames

func (x *Feed) GetAssetNames() []string

func (*Feed) GetAssetTypes

func (x *Feed) GetAssetTypes() []string

func (*Feed) GetContentType

func (x *Feed) GetContentType() ContentType

func (*Feed) GetFeedOutputConfig

func (x *Feed) GetFeedOutputConfig() *FeedOutputConfig

func (*Feed) GetName

func (x *Feed) GetName() string

func (*Feed) ProtoMessage

func (*Feed) ProtoMessage()

func (*Feed) ProtoReflect

func (x *Feed) ProtoReflect() protoreflect.Message

func (*Feed) Reset

func (x *Feed) Reset()

func (*Feed) String

func (x *Feed) String() string

type FeedOutputConfig

type FeedOutputConfig struct {

	// Asset feed destination.
	//
	// Types that are assignable to Destination:
	//
	//	*FeedOutputConfig_PubsubDestination
	Destination isFeedOutputConfig_Destination `protobuf_oneof:"destination"`
	// contains filtered or unexported fields
}

Output configuration for asset feed destination.

func (*FeedOutputConfig) Descriptor deprecated

func (*FeedOutputConfig) Descriptor() ([]byte, []int)

Deprecated: Use FeedOutputConfig.ProtoReflect.Descriptor instead.

func (*FeedOutputConfig) GetDestination

func (m *FeedOutputConfig) GetDestination() isFeedOutputConfig_Destination

func (*FeedOutputConfig) GetPubsubDestination

func (x *FeedOutputConfig) GetPubsubDestination() *PubsubDestination

func (*FeedOutputConfig) ProtoMessage

func (*FeedOutputConfig) ProtoMessage()

func (*FeedOutputConfig) ProtoReflect

func (x *FeedOutputConfig) ProtoReflect() protoreflect.Message

func (*FeedOutputConfig) Reset

func (x *FeedOutputConfig) Reset()

func (*FeedOutputConfig) String

func (x *FeedOutputConfig) String() string

type FeedOutputConfig_PubsubDestination

type FeedOutputConfig_PubsubDestination struct {
	// Destination on Pub/Sub.
	PubsubDestination *PubsubDestination `protobuf:"bytes,1,opt,name=pubsub_destination,json=pubsubDestination,proto3,oneof"`
}

type GcsDestination

type GcsDestination struct {

	// Required.
	//
	// Types that are assignable to ObjectUri:
	//
	//	*GcsDestination_Uri
	ObjectUri isGcsDestination_ObjectUri `protobuf_oneof:"object_uri"`
	// contains filtered or unexported fields
}

A Cloud Storage location.

func (*GcsDestination) Descriptor deprecated

func (*GcsDestination) Descriptor() ([]byte, []int)

Deprecated: Use GcsDestination.ProtoReflect.Descriptor instead.

func (*GcsDestination) GetObjectUri

func (m *GcsDestination) GetObjectUri() isGcsDestination_ObjectUri

func (*GcsDestination) GetUri

func (x *GcsDestination) GetUri() string

func (*GcsDestination) ProtoMessage

func (*GcsDestination) ProtoMessage()

func (*GcsDestination) ProtoReflect

func (x *GcsDestination) ProtoReflect() protoreflect.Message

func (*GcsDestination) Reset

func (x *GcsDestination) Reset()

func (*GcsDestination) String

func (x *GcsDestination) String() string

type GcsDestination_Uri

type GcsDestination_Uri struct {
	// The URI of the Cloud Storage object. It's the same URI that is used by
	// gsutil. For example: "gs://bucket_name/object_name". See [Viewing and
	// Editing Object
	// Metadata](https://cloud.google.com/storage/docs/viewing-editing-metadata)
	// for more information.
	Uri string `protobuf:"bytes,1,opt,name=uri,proto3,oneof"`
}

type GetFeedRequest

type GetFeedRequest struct {

	// Required. The name of the Feed and it must be in the format of:
	// projects/project_number/feeds/feed_id
	// folders/folder_number/feeds/feed_id
	// organizations/organization_number/feeds/feed_id
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Get asset feed request.

func (*GetFeedRequest) Descriptor deprecated

func (*GetFeedRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetFeedRequest.ProtoReflect.Descriptor instead.

func (*GetFeedRequest) GetName

func (x *GetFeedRequest) GetName() string

func (*GetFeedRequest) ProtoMessage

func (*GetFeedRequest) ProtoMessage()

func (*GetFeedRequest) ProtoReflect

func (x *GetFeedRequest) ProtoReflect() protoreflect.Message

func (*GetFeedRequest) Reset

func (x *GetFeedRequest) Reset()

func (*GetFeedRequest) String

func (x *GetFeedRequest) String() string

type ListFeedsRequest

type ListFeedsRequest struct {

	// Required. The parent project/folder/organization whose feeds are to be
	// listed. It can only be using project/folder/organization number (such as
	// "folders/12345")", or a project ID (such as "projects/my-project-id").
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// contains filtered or unexported fields
}

List asset feeds request.

func (*ListFeedsRequest) Descriptor deprecated

func (*ListFeedsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListFeedsRequest.ProtoReflect.Descriptor instead.

func (*ListFeedsRequest) GetParent

func (x *ListFeedsRequest) GetParent() string

func (*ListFeedsRequest) ProtoMessage

func (*ListFeedsRequest) ProtoMessage()

func (*ListFeedsRequest) ProtoReflect

func (x *ListFeedsRequest) ProtoReflect() protoreflect.Message

func (*ListFeedsRequest) Reset

func (x *ListFeedsRequest) Reset()

func (*ListFeedsRequest) String

func (x *ListFeedsRequest) String() string

type ListFeedsResponse

type ListFeedsResponse struct {

	// A list of feeds.
	Feeds []*Feed `protobuf:"bytes,1,rep,name=feeds,proto3" json:"feeds,omitempty"`
	// contains filtered or unexported fields
}

func (*ListFeedsResponse) Descriptor deprecated

func (*ListFeedsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListFeedsResponse.ProtoReflect.Descriptor instead.

func (*ListFeedsResponse) GetFeeds

func (x *ListFeedsResponse) GetFeeds() []*Feed

func (*ListFeedsResponse) ProtoMessage

func (*ListFeedsResponse) ProtoMessage()

func (*ListFeedsResponse) ProtoReflect

func (x *ListFeedsResponse) ProtoReflect() protoreflect.Message

func (*ListFeedsResponse) Reset

func (x *ListFeedsResponse) Reset()

func (*ListFeedsResponse) String

func (x *ListFeedsResponse) String() string

type OutputConfig

type OutputConfig struct {

	// Asset export destination.
	//
	// Types that are assignable to Destination:
	//
	//	*OutputConfig_GcsDestination
	Destination isOutputConfig_Destination `protobuf_oneof:"destination"`
	// contains filtered or unexported fields
}

Output configuration for export assets destination.

func (*OutputConfig) Descriptor deprecated

func (*OutputConfig) Descriptor() ([]byte, []int)

Deprecated: Use OutputConfig.ProtoReflect.Descriptor instead.

func (*OutputConfig) GetDestination

func (m *OutputConfig) GetDestination() isOutputConfig_Destination

func (*OutputConfig) GetGcsDestination

func (x *OutputConfig) GetGcsDestination() *GcsDestination

func (*OutputConfig) ProtoMessage

func (*OutputConfig) ProtoMessage()

func (*OutputConfig) ProtoReflect

func (x *OutputConfig) ProtoReflect() protoreflect.Message

func (*OutputConfig) Reset

func (x *OutputConfig) Reset()

func (*OutputConfig) String

func (x *OutputConfig) String() string

type OutputConfig_GcsDestination

type OutputConfig_GcsDestination struct {
	// Destination on Cloud Storage.
	GcsDestination *GcsDestination `protobuf:"bytes,1,opt,name=gcs_destination,json=gcsDestination,proto3,oneof"`
}

type PubsubDestination

type PubsubDestination struct {

	// The name of the Pub/Sub topic to publish to.
	// For example: `projects/PROJECT_ID/topics/TOPIC_ID`.
	Topic string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
	// contains filtered or unexported fields
}

A Pub/Sub destination.

func (*PubsubDestination) Descriptor deprecated

func (*PubsubDestination) Descriptor() ([]byte, []int)

Deprecated: Use PubsubDestination.ProtoReflect.Descriptor instead.

func (*PubsubDestination) GetTopic

func (x *PubsubDestination) GetTopic() string

func (*PubsubDestination) ProtoMessage

func (*PubsubDestination) ProtoMessage()

func (*PubsubDestination) ProtoReflect

func (x *PubsubDestination) ProtoReflect() protoreflect.Message

func (*PubsubDestination) Reset

func (x *PubsubDestination) Reset()

func (*PubsubDestination) String

func (x *PubsubDestination) String() string

type Resource

type Resource struct {

	// The API version. Example: `v1`
	Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
	// The URL of the discovery document containing the resource's JSON schema.
	// Example:
	// `https://www.googleapis.com/discovery/v1/apis/compute/v1/rest`
	//
	// This value is unspecified for resources that do not have an API based on a
	// discovery document, such as Cloud Bigtable.
	DiscoveryDocumentUri string `protobuf:"bytes,2,opt,name=discovery_document_uri,json=discoveryDocumentUri,proto3" json:"discovery_document_uri,omitempty"`
	// The JSON schema name listed in the discovery document. Example:
	// `Project`
	//
	// This value is unspecified for resources that do not have an API based on a
	// discovery document, such as Cloud Bigtable.
	DiscoveryName string `protobuf:"bytes,3,opt,name=discovery_name,json=discoveryName,proto3" json:"discovery_name,omitempty"`
	// The REST URL for accessing the resource. An HTTP `GET` request using this
	// URL returns the resource itself. Example:
	// `https://cloudresourcemanager.googleapis.com/v1/projects/my-project-123`
	//
	// This value is unspecified for resources without a REST API.
	ResourceUrl string `protobuf:"bytes,4,opt,name=resource_url,json=resourceUrl,proto3" json:"resource_url,omitempty"`
	// The full name of the immediate parent of this resource. See
	// [Resource
	// Names](https://cloud.google.com/apis/design/resource_names#full_resource_name)
	// for more information.
	//
	// For Google Cloud assets, this value is the parent resource defined in the
	// [IAM policy
	// hierarchy](https://cloud.google.com/iam/docs/overview#policy_hierarchy).
	// Example:
	// `//cloudresourcemanager.googleapis.com/projects/my_project_123`
	//
	// For third-party assets, this field may be set differently.
	Parent string `protobuf:"bytes,5,opt,name=parent,proto3" json:"parent,omitempty"`
	// The content of the resource, in which some sensitive fields are removed
	// and may not be present.
	Data *structpb.Struct `protobuf:"bytes,6,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

A representation of a Google Cloud resource.

func (*Resource) Descriptor deprecated

func (*Resource) Descriptor() ([]byte, []int)

Deprecated: Use Resource.ProtoReflect.Descriptor instead.

func (*Resource) GetData

func (x *Resource) GetData() *structpb.Struct

func (*Resource) GetDiscoveryDocumentUri

func (x *Resource) GetDiscoveryDocumentUri() string

func (*Resource) GetDiscoveryName

func (x *Resource) GetDiscoveryName() string

func (*Resource) GetParent

func (x *Resource) GetParent() string

func (*Resource) GetResourceUrl

func (x *Resource) GetResourceUrl() string

func (*Resource) GetVersion

func (x *Resource) GetVersion() string

func (*Resource) ProtoMessage

func (*Resource) ProtoMessage()

func (*Resource) ProtoReflect

func (x *Resource) ProtoReflect() protoreflect.Message

func (*Resource) Reset

func (x *Resource) Reset()

func (*Resource) String

func (x *Resource) String() string

type TemporalAsset

type TemporalAsset struct {

	// The time window when the asset data and state was observed.
	Window *TimeWindow `protobuf:"bytes,1,opt,name=window,proto3" json:"window,omitempty"`
	// Whether the asset has been deleted or not.
	Deleted bool `protobuf:"varint,2,opt,name=deleted,proto3" json:"deleted,omitempty"`
	// An asset in Google Cloud.
	Asset *Asset `protobuf:"bytes,3,opt,name=asset,proto3" json:"asset,omitempty"`
	// contains filtered or unexported fields
}

An asset in Google Cloud and its temporal metadata, including the time window when it was observed and its status during that window.

func (*TemporalAsset) Descriptor deprecated

func (*TemporalAsset) Descriptor() ([]byte, []int)

Deprecated: Use TemporalAsset.ProtoReflect.Descriptor instead.

func (*TemporalAsset) GetAsset

func (x *TemporalAsset) GetAsset() *Asset

func (*TemporalAsset) GetDeleted

func (x *TemporalAsset) GetDeleted() bool

func (*TemporalAsset) GetWindow

func (x *TemporalAsset) GetWindow() *TimeWindow

func (*TemporalAsset) ProtoMessage

func (*TemporalAsset) ProtoMessage()

func (*TemporalAsset) ProtoReflect

func (x *TemporalAsset) ProtoReflect() protoreflect.Message

func (*TemporalAsset) Reset

func (x *TemporalAsset) Reset()

func (*TemporalAsset) String

func (x *TemporalAsset) String() string

type TimeWindow

type TimeWindow struct {

	// Start time of the time window (exclusive).
	StartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// End time of the time window (inclusive). If not specified, the current
	// timestamp is used instead.
	EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// contains filtered or unexported fields
}

A time window specified by its `start_time` and `end_time`.

func (*TimeWindow) Descriptor deprecated

func (*TimeWindow) Descriptor() ([]byte, []int)

Deprecated: Use TimeWindow.ProtoReflect.Descriptor instead.

func (*TimeWindow) GetEndTime

func (x *TimeWindow) GetEndTime() *timestamppb.Timestamp

func (*TimeWindow) GetStartTime

func (x *TimeWindow) GetStartTime() *timestamppb.Timestamp

func (*TimeWindow) ProtoMessage

func (*TimeWindow) ProtoMessage()

func (*TimeWindow) ProtoReflect

func (x *TimeWindow) ProtoReflect() protoreflect.Message

func (*TimeWindow) Reset

func (x *TimeWindow) Reset()

func (*TimeWindow) String

func (x *TimeWindow) String() string

type UnimplementedAssetServiceServer

type UnimplementedAssetServiceServer struct {
}

UnimplementedAssetServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedAssetServiceServer) CreateFeed

func (UnimplementedAssetServiceServer) DeleteFeed

func (UnimplementedAssetServiceServer) GetFeed

func (UnimplementedAssetServiceServer) ListFeeds

func (UnimplementedAssetServiceServer) UpdateFeed

type UnsafeAssetServiceServer added in v1.22.0

type UnsafeAssetServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAssetServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AssetServiceServer will result in compilation errors.

type UpdateFeedRequest

type UpdateFeedRequest struct {

	// Required. The new values of feed details. It must match an existing feed
	// and the field `name` must be in the format of:
	// projects/project_number/feeds/feed_id or
	// folders/folder_number/feeds/feed_id or
	// organizations/organization_number/feeds/feed_id.
	Feed *Feed `protobuf:"bytes,1,opt,name=feed,proto3" json:"feed,omitempty"`
	// Required. Only updates the `feed` fields indicated by this mask.
	// The field mask must not be empty, and it must not contain fields that
	// are immutable or only set by the server.
	UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// contains filtered or unexported fields
}

Update asset feed request.

func (*UpdateFeedRequest) Descriptor deprecated

func (*UpdateFeedRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateFeedRequest.ProtoReflect.Descriptor instead.

func (*UpdateFeedRequest) GetFeed

func (x *UpdateFeedRequest) GetFeed() *Feed

func (*UpdateFeedRequest) GetUpdateMask

func (x *UpdateFeedRequest) GetUpdateMask() *fieldmaskpb.FieldMask

func (*UpdateFeedRequest) ProtoMessage

func (*UpdateFeedRequest) ProtoMessage()

func (*UpdateFeedRequest) ProtoReflect

func (x *UpdateFeedRequest) ProtoReflect() protoreflect.Message

func (*UpdateFeedRequest) Reset

func (x *UpdateFeedRequest) Reset()

func (*UpdateFeedRequest) String

func (x *UpdateFeedRequest) String() string

Jump to